import os
import json
import logging

import requests


def host():
    return os.environ.get("AUTOSCALE_HOST", "")


def new(data, token):
    url = "{}/datasource".format(host())
    headers = {"Authorization": token}
    d = json.dumps(data)
    logging.error("trying to add new datasource - {} - {}".format(url, d))
    response = requests.post(url, data=d, headers=headers)
    logging.error("add new datasource response - {}".format(response))
    return response


def list(token):
    url = "{}/datasource?public=true".format(host())
    headers = {"Authorization": token}
    response = requests.get(url, headers=headers)
    return response


def remove(name, token):
    url = "{}/datasource/{}".format(host(), name)
    headers = {"Authorization": token}
    response = requests.delete(url, headers=headers)
    return response


def get(name, token):
    url = "{}/datasource/{}".format(host(), name)
    headers = {"Authorization": token}
    response = requests.get(url, headers=headers)
    return response



import os

import requests


def host():
    return os.environ.get("AUTOSCALE_HOST", "")


def list(alarm_name, token):
    url = "{}/alarm/{}/event".format(host(), alarm_name)
    headers = {"Authorization": token}
    response = requests.get(url, headers=headers)
    return response



import logging
import traceback
import sys
from django.http import Http404


class LogMiddleware(object):

    def process_exception(self, request, exception):
        exc_info = sys.exc_info()

        if not isinstance(exception, Http404):
            logging.error("######################## Exception #############################")
            logging.error('\n'.join(traceback.format_exception(*(exc_info or sys.exc_info()))))
            logging.error("################################################################")



from django import forms


def datasource_list(token):
    from tsuru_autoscale.datasource import client
    dl = client.list(token).json() or []
    return [(ds['Name'], ds['Name']) for ds in dl]


def action_list(token):
    from tsuru_autoscale.action import client
    al = client.list(token).json() or []
    return [(ds['Name'], ds['Name']) for ds in al]


def service_instance_list(token):
    from tsuru_autoscale.alarm import client
    al = client.service_instance_list(token).json() or []
    return [(ds['Name'], ds['Name']) for ds in al]


class AlarmForm(forms.Form):
    name = forms.CharField()
    expression = forms.CharField()
    enabled = forms.BooleanField(initial=True)
    wait = forms.IntegerField()
    datasource = forms.ChoiceField()
    actions = forms.MultipleChoiceField()
    instance = forms.ChoiceField()



from django.test import TestCase
from django.test.client import RequestFactory

from auth.middleware import AuthMiddleware


class TestVerifyTokenMiddleware(TestCase):
    def test_process_request_without_token(self):
        middleware = AuthMiddleware()

        request_mock = RequestFactory().get("/")
        result = middleware.process_request(request_mock)
        self.assertEqual(result.status_code, 401)

    def test_process_request(self):
        middleware = AuthMiddleware()

        request_mock = RequestFactory().get("/?TSURU_TOKEN=bla")
        result = middleware.process_request(request_mock)
        self.assertFalse(result)
        self.assertEqual(request_mock.token, "bla")



from setuptools import setup, find_packages
from tsuru_autoscale import __version__


setup(
    name="tsuru_autoscale",
    url="https://github.com/tsuru/tsuru-autoscale-dashboard",
    version=__version__,
    packages=find_packages(),
    description="Web dashboard for tsuru autoscale service",
    author="tsuru",
    author_email="tsuru@corp.globo.com",
    include_package_data=True,
    install_requires=[
        "Django>=1.10.2",
        "requests>=2.8.1",
    ],
)
